##  Setup in SAP Signavio
To configure the integration, you need a user account in SAP Signavio with appropriate read and write permissions. These credentials are entered into SAP LeanIX for authentication during setup.
We recommend creating a dedicated user account with an 'API Edition' license. This license enables seamless integration with SAP Signavio's API by bypassing the Single Sign-On (SSO) login process. A dedicated account also ensures proper access management and continuity.
![Choosing the API Edition License for User Account](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27516ada7a441014b9bdbc949a6bcc43_LowRes.jpg)
Choosing the API Edition License for User Account
If the 'API Edition' license is not available in your SAP Signavio workspace, you can request one by opening a support ticket with SAP Signavio. Be sure to include your tenant ID in the support request to help expedite the process. This license is provided at no additional cost.
Note that accounts with this license cannot access the SAP Signavio application through the user interface.
